@@ -530,7 +530,7 @@ def InceptionResNetV2():
 
 	return model
 
-def loadModel():
+def loadModel(url = 'https://drive.google.com/uc?id=1971Xk5RwedbudGgTIrGAL4F7Aifu7id1'):
 	model = InceptionResNetV2()
 	
 	#-----------------------------------
@@ -540,7 +540,6 @@ def loadModel():
 	if os.path.isfile(home+'/.deepface/weights/facenet_weights.h5') != True:
 		print("facenet_weights.h5 will be downloaded...")
 		
-		url = 'https://drive.google.com/uc?id=1971Xk5RwedbudGgTIrGAL4F7Aifu7id1'
 		output = home+'/.deepface/weights/facenet_weights.h5'
 		gdown.download(url, output, quiet=False)
 	
